| crew_class_client | R Documentation |
R6 client class.R6 class for mirai clients.
See crew_client().
hostSee crew_client().
portSee crew_client().
tlsSee crew_client().
serializationSee crew_client().
profileCompute profile of the client.
seconds_intervalSee crew_client().
seconds_timeoutSee crew_client().
relayRelay object for event-driven programming on a downstream condition variable.
startedWhether the client is started.
urlClient websocket URL.
new()mirai client constructor.
crew_class_client$new( host = NULL, port = NULL, tls = NULL, serialization = NULL, profile = NULL, seconds_interval = NULL, seconds_timeout = NULL, relay = NULL )
hostArgument passed from crew_client().
portArgument passed from crew_client().
tlsArgument passed from crew_client().
serializationArgument passed from crew_client().
profileArgument passed from crew_client().
seconds_intervalArgument passed from crew_client().
seconds_timeoutArgument passed from crew_client().
relayArgument passed from crew_client().
An R6 object with the client.
if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
client <- crew_client()
client$start()
client$log()
client$terminate()
}
validate()Validate the client.
crew_class_client$validate()
NULL (invisibly).
set_started()Register the client as started.
crew_class_client$set_started()
Exported to implement the sequential controller. Only meant to be called manually inside the client or the sequential controller.
NULL (invisibly).
start()Start listening for workers on the available sockets.
crew_class_client$start()
NULL (invisibly).
terminate()Stop the mirai client and disconnect from the worker websockets.
crew_class_client$terminate()
NULL (invisibly).
status()Get the counters from mirai::info().
crew_class_client$status()
A named integer vector of task counts (awaiting, executing, completed) as well as the number of worker connections.
pids()Deprecated on 2025-08-26 in crew version 1.2.1.9005.
crew_class_client$pids()
The integer process ID of the current process.
Other client:
crew_client()
if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
client <- crew_client()
client$start()
client$log()
client$terminate()
}
## ------------------------------------------------
## Method `crew_class_client$new`
## ------------------------------------------------
if (identical(Sys.getenv("CREW_EXAMPLES"), "true")) {
client <- crew_client()
client$start()
client$log()
client$terminate()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.